@@ -24,7 +24,7 @@
 import socket, os
 
 # The current version of duplicity
-version = "0.6.09"
+version = "0.6.11"
 
 # The name of the current host, or None if it cannot be set
 hostname = socket.getfqdn()
@@ -107,10 +107,16 @@ force = None
 # be deleted.
 remove_time = None
 
-# If set, signifies the number of backups chains to keep when perfroming
-# a --remove-all-but-n-full.
+# If set, signifies the number of backups chains to keep when performing
+# a remove-all-but-n-full.
 keep_chains = None
 
+# If set, signifies that remove-all-but-n-full in progress
+remove_all_but_n_full_mode = None
+
+# If set, signifies that remove-all-inc-of-but-n-full in progress (variant of remove-all-but-n-full)
+remove_all_inc_of_but_n_full_mode = None
+
 # Don't actually do anything, but still report what would be done
 dry_run = False
 
@@ -145,6 +151,10 @@ s3_use_new_style = False
 # support european for now).
 s3_european_buckets = False
 
+# Whether to use plain HTTP (without SSL) to send data to S3
+# See <https://bugs.launchpad.net/duplicity/+bug/433970>.
+s3_unencrypted_connection = False
+
 # Whether to use S3 Reduced Redudancy Storage
 s3_use_rrs = False
 
